# invert_single_rgb()

## How to use

1. ```python
   from colorcodetools.rgb.invert import invert_single_rgb
   invert_single_rgb(255)
   ```
2. ```python
   import colorcodetools
   colorcodetools.rgb.invert.invert_single_rgb(r/g/b)
   ```

## Parameters

1. Required parameters:

   - rgb:  
      Enter a single rgb code part which should be inverted.
     - `type: int`
     - `default: None`
     - `example: 255`

## Return value

- `type: boolean or int`
